@@ -56,14 +56,13 @@ static const char *ver_data_members[] = {
 };
 
 static int
-checkSelRules(struct deb_archive *deb, const char *originID, struct group *grp)
+checkSelRules(struct dpkg_ar *deb, const char *originID, struct group *grp)
 {
     int opt_count = 0;
     struct match *mtc;
     int len;
 
     for (mtc = grp->matches; mtc; mtc = mtc->next) {
-
         ds_printf(DS_LEV_VER, "      Processing '%s' key...", mtc->name);
 
         /* If we have an ID for this match, check to make sure it exists, and
@@ -89,7 +88,8 @@ checkSelRules(struct deb_archive *deb, const char *originID, struct group *grp)
             return 0;
         }
         /* This would mean this is Optional, so we ignore it for now */
-        if (!len) continue;
+        if (!len)
+            continue;
 
         /* Kick up the count once for checking later */
         if (mtc->type == OPTIONAL_MATCH)
@@ -106,7 +106,7 @@ checkSelRules(struct deb_archive *deb, const char *originID, struct group *grp)
 }
 
 static int
-verifyGroupRules(struct deb_archive *deb, const char *originID, struct group *grp)
+verifyGroupRules(struct dpkg_ar *deb, const char *originID, struct group *grp)
 {
     struct dpkg_error err;
     char *tmp_sig, *tmp_data;
@@ -169,7 +169,6 @@ verifyGroupRules(struct deb_archive *deb, const char *originID, struct group *gr
     fd = -1;
 
     for (mtc = grp->matches; mtc; mtc = mtc->next) {
-
 	ds_printf(DS_LEV_VER, "      Processing '%s' key...", mtc->name);
 
 	/* If we have an ID for this match, check to make sure it exists, and
@@ -192,7 +191,8 @@ verifyGroupRules(struct deb_archive *deb, const char *originID, struct group *gr
 	}
 
 	/* This would mean this is Optional, so we ignore it for now */
-	if (!len) continue;
+	if (!len)
+            continue;
 
 	/* let's get our temp file */
 	tmp_sig = path_make_temp_template("debsig-sig");
@@ -247,7 +247,7 @@ fail_and_close:
 }
 
 static int
-checkIsDeb(struct deb_archive *deb)
+checkIsDeb(struct dpkg_ar *deb)
 {
     int i;
     const char *member;
@@ -280,7 +280,9 @@ checkIsDeb(struct deb_archive *deb)
     return 1;
 }
 
-static void outputVersion(void) {
+static void
+outputVersion(void)
+{
     printf(
 "Debsig Program Version - "VERSION"\n"
 "  Signature Version - "SIG_VERSION"\n"
@@ -295,7 +297,9 @@ outputBadUsage(void)
     ohshit("Use --help for program usage information.");
 }
 
-static void outputUsage(void) {
+static void
+outputUsage(void)
+{
     printf("Usage: %s [<option>...] <deb>\n\n", dpkg_get_progname());
 
     printf(
@@ -327,8 +331,10 @@ ds_print_fatal_error(const char *emsg, const void *data)
     ds_printf(DS_LEV_ERR, "%s", emsg);
 }
 
-int main(int argc, char *argv[]) {
-    struct deb_archive deb = { .name = NULL, .fd = -1, };
+int
+main(int argc, char *argv[])
+{
+    struct dpkg_ar *deb;
     struct policy *pol = NULL;
     char *originID;
     char buf[8192], pol_file[8192], *force_file = NULL;
@@ -410,18 +416,15 @@ int main(int argc, char *argv[]) {
 	outputBadUsage();
     }
 
-    deb.name = argv[i];
-    deb.fd = open(deb.name, O_RDONLY);
-    if (deb.fd < 0)
-	ohshite("could not open %s", deb.name);
+    deb = dpkg_ar_open(argv[i]);
 
     if (!list_only)
-	ds_printf(DS_LEV_VER, "Starting verification for: %s", deb.name);
+	ds_printf(DS_LEV_VER, "Starting verification for: %s", deb->name);
 
-    if (!checkIsDeb(&deb))
-	ohshit("%s does not appear to be a deb format package", deb.name);
+    if (!checkIsDeb(deb))
+	ohshit("%s does not appear to be a deb format package", deb->name);
 
-    originID = getSigKeyID(&deb, "origin");
+    originID = getSigKeyID(deb, "origin");
     if (originID == NULL)
 	ds_fail_printf(DS_FAIL_NOSIGS, "Origin Signature check failed. This deb might not be signed.\n");
 
@@ -449,12 +452,13 @@ int main(int argc, char *argv[]) {
 	ds_printf(DS_LEV_VER, "  Parsing policy file: %s", pol_file);
 	pol = parsePolicyFile(pol_file);
 
-	if (pol == NULL) continue;
+	if (pol == NULL)
+	    continue;
 
 	/* Now let's see if this policy's selection is useful for this .deb  */
 	ds_printf(DS_LEV_VER, "    Checking Selection group(s).");
 	for (grp = pol->sels; grp != NULL; grp = grp->next) {
-	    if (!checkSelRules(&deb, originID, grp)) {
+	    if (!checkSelRules(deb, originID, grp)) {
 		clear_policy();
 		ds_printf(DS_LEV_VER, "    Selection group failed checks.");
 		pol = NULL;
@@ -486,9 +490,9 @@ int main(int argc, char *argv[]) {
     ds_printf(DS_LEV_VER, "    Checking Verification group(s).");
 
     for (grp = pol->vers; grp; grp = grp->next) {
-	if (!verifyGroupRules(&deb, originID, grp)) {
+	if (!verifyGroupRules(deb, originID, grp)) {
 	    ds_printf(DS_LEV_VER, "    Verification group failed checks.");
-	    ds_fail_printf(DS_FAIL_BADSIG, "Failed verification for %s.", deb.name);
+	    ds_fail_printf(DS_FAIL_BADSIG, "Failed verification for %s.", deb->name);
 	}
     }
 
